\name{angina}
\alias{angina}
\non_function{}
\title{ Dose Response Data Set }
\usage{data(angina)}
\description{
 Dose response study of an angina drug; data set taken from 
 Westfall et al. (1999, p. 164). Different trend tests in a balanced 
 one-way layout.
}
\format{
  This data frame contains the following variables
  \describe{
    \item{dose}{Treatments at 5 levels: \code{0}, \code{1}, \code{2},
                \code{3}, \code{4}}
    \item{response}{Response variable: change from pretreatment 
                    as measured in minutes of pain-free walking.}
  }
}
\details{
  See Westfall et al. (1999, p. 164)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(angina)

# perform a dose-response analysis using simultaneous confidence 
# intervals for Williams' contrasts
summary(ci <- simint(response~dose, data=angina, alternative="greater",
               type="Williams"))
plot(ci, cex.axis=1.75, lwd=1.5)

# consider the same data set as a changepoint problem
summary(simint(response~dose, data=angina, alternative="greater",
               type="Changepoint"))

# compute now adjusted p-values for McDermott's test on trend
summary(simtest(response~dose, data=angina, type="McDermott",
                alternative="greater",ttype="logical"))
}
\keyword{datasets}

\eof
\name{cholesterol}
\alias{cholesterol}
\non_function{}
\title{ Cholesterol Reduction Data Set }
\usage{data(cholesterol)}
\description{
 Cholesterol reduction for five treatments; data set taken from 
 Westfall et al. (1999, p. 153). All pairwise comparisons according 
 to Tukey in a balanced one-way layout.
}
\format{
  This data frame contains the following variables
  \describe{
    \item{trt}{Treatment at 5 levels, see below.}
    \item{response}{Response variable.}
  }
}
\details{
  See Westfall et al. (1999, p. 153). The treatment formulations 
are defined as: 20mg one a day (\code{1time}), 10mg twice a day
(\code{2times})
and 5mg four times a day (\code{4times}). In addition, two competing drugs
were used as control (\code{drugD}) and (\code{drugE}).
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(cholesterol)

# adjusted p-values for all-pairwise comparisons in a one-way layout 
# tests for restricted combinations
simtest(response ~ trt, data=cholesterol, type="Tukey",
        ttype="logical")

# adjusted p-values all-pairwise comparisons in a one-way layout 
# (tests for free combinations -> p-values will be larger)
simtest(response ~ trt, data=cholesterol, type="Tukey",
        ttype="free")


# the following lines illustrate the basic principles of
# parameter estimation used in all functions in this package
# and how the low-level functions can be used with raw parameter
# estimates.

# the full design matrix (with reduced rank!)
x <- cbind(1, 
           matrix(c(rep(c(rep(1,10), rep(0,50)), 4), 
                    rep(1, 10)), nrow = 50))
y <- cholesterol$response

xpxi   <- mginv(t(x) \%*\% x)
rankx  <- sum(diag((xpxi \%*\% (t(x) \%*\% x))))
n      <- nrow(x)
p      <- ncol(x)
df     <- round(n-rankx)

# parameter estimates and their correlation
parm   <- xpxi \%*\% t(x) \%*\% y
mse    <- t(y-x \%*\% parm) \%*\% (y-x \%*\% parm)/df
covm   <- mse[1,1]*xpxi

# the contrast matrix
contrast <- contrMat(table(cholesterol$trt), type="Tukey")

# use the work-horse directly (and add zero column for the intercept)

csimint(estpar=parm, df=df, covm=covm, cmatrix=cbind(0, contrast))    
csimtest(estpar=parm, df=df, covm=covm, cmatrix=cbind(0, contrast),
         ttype="logical")      

# only a subset of all pairwise hypotheses:
#
# * drug D versus all other formulations and
# * all pairwise comparisions for "1time", "2times" and "4times"
#
csubset = contrast[c(1,3,5,6,8,10),]
csubset
simint(response ~ trt, data=cholesterol, cmatrix = csubset)

}
\keyword{datasets}

\eof
\name{contrMat}
\alias{contr.Dunnett}
\alias{contrMat}
\title{ Contrast Matrices }
\description{
  Computes contrast matrices for several multiple comparision procedures.
}
\usage{
contrMat(n, type=c("Dunnett", "Tukey", "Sequen", "AVE", 
                   "Changepoint", "Williams", "Marcus", 
                   "McDermott", "Tetrade"), nlevel = NULL, base = 1)
contr.Dunnett(n, base = 1, contrasts=TRUE)
}
\arguments{
  \item{n}{ a (possibly named) vector of sample sizes for each group or a
            vector of factor levels. }
  \item{type}{ type of contrast. }
  \item{nlevel}{ number of levels of two factors (for \code{type="Tetrade"}
                  only).}
  \item{contrasts}{ a logical indicating whether contrasts should be
                  computed.}
  \item{base}{ an integer specifying which group is considered the baseline
          group for Dunnett contrasts. Ignored if \code{contrasts} is \code{FALSE}.}

}
\details{
  Computes the requested matrix of contrasts.
}
\value{
  The matrix of contrasts with appropriate rownames is returned. 
}
\references{
  Frank Bretz, Alan Genz and Ludwig A. Hothorn (2001), On the numerical 
  availability of multiple comparison procedures. \emph{Biometrical Journal},
  \bold{43}(5), 645--656.
} 
\author{ Frank Bretz <bretz@ifgb.uni-hannover.de> and  \cr
 Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\examples{
 n <- c(10,20,30,40)
 a <- 2
 b <- 3
 names(n) <- paste("group", 1:4, sep="")
 contrMat(n)	# Dunnett is default
 contrMat(n, base=2)	# use second level as baseline
 contr.Dunnett(names(n))  # it Moore-Penrose Inverse
 contrMat(n, type="Tukey")
 contrMat(n, type="Sequen")
 contrMat(n, type="AVE")
 contrMat(n, type="Changepoint")
 contrMat(n, type="Williams")
 contrMat(n, type="Marcus")
 contrMat(n, type="McDermott")
 contrMat(n, type="Tetrade", nlevel=c(a,b))
}
\keyword{misc}

\eof
\name{csimint}
\alias{csimint}
\title{ Simultaneous Confidence Intervals Based on Parameter Estimates }
\description{
Computes simultaneous intervals for several multiple procedures based on
precomputed parameter estimates. 
}
\usage{
csimint(estpar, df, covm, cmatrix = NULL, 
        ctype = "user-defined", conf.level = 0.95, 
        alternative = c("two.sided", "less", "greater"),
        asympt = FALSE, eps = 0.001, maxpts = 1e+06)
}
\arguments{
  \item{estpar}{ estimated parameter vector. }
  \item{df}{ degrees of freedom. }
  \item{covm}{ estimated covariance matrix of \code{estpar}. }
  \item{cmatrix}{ contrast matrix. }
  \item{ctype}{ a string decribing the kind of contrast matrix used. Only
used for printing in \code{\link{print.hmtest}}. }
  \item{conf.level}{confidence level. }
  \item{alternative}{ the alternative hypothesis must be
    one of \code{"two.sided"} (default), \code{"greater"} or
    \code{"less"}.  You can specify just the initial letter. }
\item{asympt}{a logical indicating whether the (exact) t-distribution or
the normal approximation should be used.}
  \item{eps}{absolute error tolerance as double.}
  \item{maxpts}{maximum number of function values as integer.}
}
\details{
  This is the work-horse for \code{\link{simint}}. If only parameter
estimates and estimates of the (co)variances are available, simultaneous
confidence intervals can be computed with this low-level function. See
\code{\link{cholesterol}} for an example.

}
\value{
an object of class \code{hmtest}
}
\references{

  Frank Bretz, Alan Genz and Ludwig A. Hothorn (2001), On the numerical 
  availability of multiple comparison procedures. \emph{Biometrical Journal},
  \bold{43}(5), 645--656.

}
\author{ Frank Bretz <bretz@ifgb.uni-hannover.de> and  \cr 
 Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\keyword{htest}

\eof
\name{csimtest}
\alias{csimtest}
\title{ Simultaneous Comparisons Based on Parameter Estimates. }
\description{
Computes multiplicity adjusted p-values based on
precomputed parameter estimates.
}
\usage{
csimtest(estpar, df, covm, cmatrix = NULL, 
         ctype = "user-defined", ttype = c("free", "logical"), 
         alternative = c("two.sided", "less", "greater"), 
         asympt = FALSE, eps = 0.001, maxpts = 1e+06)
}
\arguments{
  \item{estpar}{ estimated parameter vector. }
  \item{df}{ degrees of freedom. }
  \item{covm}{ estimated covariance matrix of \code{estpar}. }
  \item{cmatrix}{ contrast matrix. }
 \item{ctype}{ a string decribing the kind of contrast matrix used. Only
used for printing in \code{\link{print.hmtestp}}. }
  \item{ttype}{Specifies whether the logical contraint method 
of Westfall (1997) will be used, or whether the uncontrained 
method will be used.}
  \item{alternative}{ the alternative hypothesis must be
    one of \code{"two.sided"} (default), \code{"greater"} or
    \code{"less"}.  You can specify just the initial letter. }
\item{asympt}{a logical indicating whether the (exact) t-distribution or
the normal approximation should be used.}
  \item{eps}{absolute error tolerance as double.}
  \item{maxpts}{maximum number of function values as integer.}
}
\details{
  This is the work-horse for \code{\link{simtest}}. If only parameter
estimates and estimates of the (co)variances are available, adjusted
p-values can be computed with this low-level function. See
\code{\link{cholesterol}} for an example.

}
\value{
an object of class \code{hmtestp}
}
\references{ 
Peter Westfall (1997), Multiple testing of general contrasts using logical
constraints and correlations, \emph{Journal of the American Statistical
Association}, \bold{92}(437), 299--306.

Frank Bretz, Alan Genz and Ludwig A. Hothorn (2001), On the numerical 
availability of multiple comparison procedures. \emph{Biometrical Journal},
\bold{43}(5), 645--656.

}
\author{ Frank Bretz <bretz@ifgb.uni-hannover.de> and  \cr 
 Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\keyword{htest}

\eof
\name{detergent}
\alias{detergent}
\non_function{}
\title{ Detergent Durability Data Set }
\usage{data(detergent)}
\description{
 Detergent durability in a fractional design experiment; data set 
 taken from Westfall et al. (1999, p. 189). Balanced incomplete block design.
}
\format{
  This data frame contains the following variables
  \describe{
    \item{detergent}{detergent at 5 levels: 1 ... 5}
    \item{block}{block at 10 levels: 1 ... 10}
    \item{plates}{Response variable: number of plates washed before 
     the foam disappears.}
  }
}
\details{
  See Westfall et al. (1999, p. 189)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{

data(detergent)

N <- rep(2, 5)

# BIBD: prepare the contrast matrix = all-pair comparisons for 
# the 5 levels of detergent

C <- contrMat(N, type="Tukey")

# adjusted p-values: either using the contrast matrix C
summary(simtest(plates ~ block+detergent, data=detergent, whichf="detergent",
                ttype="logical", cmatrix=C))

# or, more easily, type="Tukey"
summary(simtest(plates ~ detergent + block, data=detergent,
        whichf="detergent", type="Tukey", ttype="logical"))


}
\keyword{datasets}

\eof
\name{litter}
\alias{litter}
\non_function{}
\title{ Litter Weights Data Set }
\usage{data(litter)}
\description{
  Dose response of litter weights in rats; data set taken from Westfall et al. (1999, p. 109). Specific dose comparisons in a dose response experiment with two covariates. 
}
\format{
  This data frame contains the following variables
  \describe{
    \item{dose}{Dosages at 4 levels: \code{0}, \code{5}, \code{50}, 
                \code{500}.}
    \item{gesttime}{Gestation time as covariate.}
    \item{number}{Number of animals in litter as covariate.}
    \item{weight}{Response variable: average post-birth weights 
                  in the entire litter.}
  }
}
\details{
  See Westfall et al. (1999, p. 109)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(litter)

# define the contrast matrix, either completly
C <- matrix(c(0,0,0,0,0,0,1,1,1,.75,.384,.887,-1,0,0,.25,.37,.113,
       0,-1,0,-.25,.246,-.339,0,0,-1,-.75,-1,-.661,0,0,0,
       0,0,0,0,0,0,0,0,0), ncol=7)
# numerate the contrasts
rownames(C) <- paste("C", 1:nrow(C), sep="")

# simultaneous confidence intervals for above comparisons 
# in an ANCOVA
summary(simint(weight ~ dose + gesttime + number, data=litter,
               alternative="greater", cmatrix=C))

# or for dose only
D <- matrix(c(1,1,1,.75,.384,.887,-1,0,0,.25,.37,.113,0,-1,0,-.25,
              .246,-.339,0,0,-1,-.75,-1,-.661),ncol = 4)
rownames(D) <- paste("D", 1:nrow(D), sep="")

summary(simint(weight ~ dose + gesttime + number, data=litter,
               whichf="dose", alternative="greater", cmatrix=D))

}
\keyword{datasets}

\eof
% file VR/MASS/ginv.Rd
% copyright (C) 1994-9 W. N. Venables and B. D. Ripley
%
% Copied from VR_6.3-2
\name{mginv}
\alias{mginv}
\title{
Generalized Inverse of a Matrix
}
\description{
Calculates the Moore-Penrose generalized inverse of a matrix
\code{X}.
}
\usage{
mginv(X, tol=sqrt(.Machine$double.eps))
}
\arguments{
\item{X}{
Matrix for which the Moore-Penrose inverse is required.
}
\item{tol}{
A relative tolerance to detect zero singular values.
}}
\value{
A MP generalized inverse matrix for \code{X}.
}
\references{
Venables & Ripley, Chapter 2. Copied from package \code{VR}.
}
\seealso{
\code{\link{solve}}, \code{\link{svd}}, \code{\link{eigen}}
}
\examples{
\dontrun{
# The function is currently defined as
function(X, tol = sqrt(.Machine$double.eps))
{
## Generalized Inverse of a Matrix
  dnx <- dimnames(X)
  if(is.null(dnx)) dnx <- vector("list", 2)
  s <- svd(X)
  nz <- s$d > tol * s$d[1]
  structure(
    if(any(nz)) s$v[, nz] \%*\% (t(s$u[, nz])/s$d[nz]) else X,
    dimnames = dnx[2:1])
}
}}
\keyword{algebra}

\eof
\name{multcomp-internal}
\alias{ct}
\title{Internal multcomp functions}
\description{
 Internal multcomp functions.
}
\usage{
ct(x, contrasts=FALSE)
}

}
\details{
  This functions are not to be called by the user.
}
\keyword{internal}

\eof
\name{multcomp}
\alias{multcomp}
\title{General Information on the multcomp Package}
\non_function{}
\description{
The \code{multcomp} package allows for multiple comparisons of
\eqn{k} groups in general linear models. We use the unifying
representations of multiple contrast tests, which include all
common multiple comparison procedures, such as the many-to-one
comparisons of Dunnett, the all-pairwise comparisons of Tukey and
many other procedures. We provide a list of 9
standard procedures (Dunnett, Tukey, Sequen, AVE, Changepoint,
Williams, Marcus, McDermott, Tetrade), where the user selects the 
comparisons of his interest. In addition, a free input interface 
for the contrast matrix allows for more special comparisons.

The comparisons itself are not restricted to balanced or simple
designs. Instead, the programs are designed to suit multiple
comparisons within the general linear model, thus allowing for
covariates, nested effects, correlated means and missing values.
The program is designed for the normal set-up with a common (possibly unknown)
variance and a known covariance matrix. But instead of using the
usual Bonferroni and Holm procedures, we take the exact
correlations between the test statistics into account by use of
the multivariate t-distribution. The resulting procedures are
therefore more powerful (the Bonferroni and Holm adjusted 
p-values are reported for reference). We also allow the user to perform an
asymptotic analysis based on the multivariate normal
distribution (as required e.g. in multiple comparisons based on
asymptotic rank transformations; assumed asymptotic normality
when comparing binomial parameters; etc.). Two functions will be
provided. The first one computes confidence intervals for the
common single step procedures (\code{\link{simint}}). 
This approach can be uniformly
improved by applying the closed testing principle, what is
implemented in the second function (\code{\link{simtest}}; 
but no confidence intervals
are available for the latter procedure). Use either \code{\link{csimint}} or
\code{\link{csimtest}} if you want to pass the estimates by hand. 

For testing and validation purposes we included some examples from Westfall
et al. (1999).
}
    
\references{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.

  Peter Westfall (1997), Multiple testing of general contrasts using logical
  constraints and correlations, \emph{Journal of the American Statistical
  Association}, \bold{92}(437), 299--306.
 
  Frank Bretz, Alan Genz and Ludwig A. Hothorn (2001), On the numerical
  availability of multiple comparison procedures. \emph{Biometrical Journal},
  \bold{43}(5), 645--656.

}
\author{
 Frank Bretz <bretz@ifgb.uni-hannover.de>,
 Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> and
 Peter Westfall <WESTFALL@ba.ttu.edu>
}
\keyword{misc}

\eof
\name{plot.hmtest}
\alias{plot.hmtest}
\title{ Plot Simultaneous Confidence Intervals }
\description{
  This method plots objects of class \code{hmtest}.
}
\usage{
\method{plot}{hmtest}(x, ltycint = 2, ltyzero = 3, main = NULL, 
                      xlab = NULL,...)
}
\arguments{
  \item{x}{an object of class \code{hmtest}}
  \item{ltycint}{integer specifying the line type of the confidence
intervals.}
  \item{ltyzero}{integer specifying the line type of the vertical line at zero.}
  \item{main}{an overall title of the plot.}
  \item{xlab}{a title for the \code{x} axis.}
  \item{\dots}{other parameters to be passed through to plotting functions.}
}
\details{
  The confidence intervals are plotted as horizontal lines.
}
\author{ Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\keyword{hplot}

\eof
\name{print.hmtest}
\alias{print.hmtest}
\title{Print Method for hmtest Object}
\description{
  Print object of class \code{"hmtest"} in nice layout.
}
\usage{
\method{print}{hmtest}(x, digits, \dots)
}
\arguments{
  \item{x}{Object of class \code{"hmtest"}.}
  \item{digits}{how many digits should be printed.}
  \item{\dots}{further arguments to be passed to or from methods.}  
}
\details{
  Prints a \code{hmtest} object.
}
\value{
  none
}
}
\keyword{htest}

\eof
\name{print.hmtestp}
\alias{print.hmtestp}
\title{Print Method for hmtestp Object}
\description{
  Print object of class \code{"hmtestp"} in nice layout.
}
\usage{
\method{print}{hmtestp}(x, digits, \dots)
}
\arguments{
  \item{x}{Object of class \code{"hmtestp"}.}
  \item{digits}{how many digits should be printed.}
  \item{\dots}{further arguments to be passed to or from methods.}  
}
\details{
  Print a \code{hmtestp} object. 
}
\value{
  none
}
\keyword{htest}

\eof
\name{recovery}
\alias{recovery}
\non_function{}
\title{ Recovery Time Data Set }
\usage{data(recovery)}
\description{
 Recovery time data set taken from Westfall 
 et al. (1999, p. 80). Many-to-one comparisons according to 
 Dunnett in an unbalanced one-way layout. 
}
\format{
  This data frame contains the following variables
  \describe{
    \item{blanket}{Blanket type at 4 levels: \code{b0}, \code{b1},
                   \code{b3}, \code{b4}.}
    \item{minutes}{Response variable: recovery time after a surgical 
                   procedure.}
  }
}
\details{
  See Westfall et al. (1999, p. 80)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(recovery)

# one-sided simultaneous confidence intervals for Dunnett 
# in the one-way layout
ci <- simint(minutes ~ blanket, data=recovery, conf.level=0.9, 
      alternative="less",eps=0.0001)
summary(ci)
plot(ci,cex.axis=1.5, lwd=1.5)


# same results, but specifying the contrast matrix by hand
C <- c(0, 0, 0, -1, -1, -1, 1, 0, 0, 0, 1, 0, 0, 0, 1)
C <- matrix(C, ncol=5)
# numerate the contrasts
rownames(C) <- paste("C", 1:nrow(C), sep="")
test <- simint(minutes~blanket, data=recovery, conf.level=0.9, 
               alternative="less",eps=0.0001, cmatrix=C)
print(test)

# same results, but more detailed information using the summary method
summary(test)
}
\keyword{datasets}

\eof
\name{respiratory}
\alias{respiratory}
\non_function{}
\title{ Respiratory Health Data Set }
\usage{data(respiratory)}
\description{
  Sub-group and whole-group analysis of a respiratory therapy drug; data set taken from Westfall et al. (1999, p. 195). Three-way ANOVA with weighted contrasts.
}
\format{
  This data frame contains the following variables
  \describe{
    \item{Treatment}{Treatment at 2 levels: \code{Active} and
\code{Placebo}.}
    \item{AgeGroup}{Age group at 2 levels: \code{Younger} and \code{Older}.}
    \item{InitHealth}{Inititial health condition at 2 levels: \code{Good}
                      and \code{Poor}.}
    \item{Score}{Response variable: time-weighted score comprised 
                 of four post-treatment evaluations.}
  }
}
\details{
  See Westfall et al. (1999, p. 195)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(respiratory)

# compute the contrast matrix in several steps 
# overall active vs. placebo
CA  <- c(0, 13, 0, 11, 0, 13, 0, 17, 0)
CP  <- c(0, 0, 14, 0, 12,  0, 19, 0, 12)
CA  <- CA/sum(CA)
CP  <- CP/sum(CP)
C1  <- CP-CA

# for older subgroup only
CAO <- c( 0, 13,  0,  0,  0, 13,  0,  0,  0 ) 
CPO <- c( 0,  0, 14,  0,  0,  0, 19,  0,  0 ) 
CAO <- CAO/sum(CAO)
CPO <- CPO/sum(CPO)
C2  <- CPO - CAO

# for younger subgroup only 
CAY <- c( 0,  0,  0, 11,  0,  0,  0, 17,  0 ) 
CPY <- c( 0,  0,  0,  0, 12,  0,  0,  0, 12 ) 
CAY <- CAY/sum(CAY)
CPY <- CPY/sum(CPY)
C3  <- CPY - CAY

# subgroup with inital good health
CAG <- c( 0, 13,  0, 11,  0,  0,  0,  0,  0 ) 
CPG <- c( 0,  0, 14,  0, 12,  0,  0,  0,  0 ) 
CAG <- CAG/sum(CAG)
CPG <- CPG/sum(CPG)
C4  <- CPG - CAG

# subgroup with inital poor health
CAP <- c( 0,  0,  0,  0,  0, 13,  0, 17,  0 ) 
CPP <- c( 0,  0,  0,  0,  0,  0, 19,  0, 12 ) 
CAP <- CAP/sum(CAP)
CPP <- CPP/sum(CPP)
C5  <- CPP - CAP

# all 4 subgroup combinations of age and initial health condition 
C6  <- c( 0, -1,  1,  0,  0,  0,  0,  0,  0 )
C7  <- c( 0,  0,  0,  0,  0, -1,  1,  0,  0 )
C8  <- c( 0,  0,  0, -1,  1,  0,  0,  0,  0 )
C9  <- c( 0,  0,  0,  0,  0,  0,  0, -1,  1 )

# contrast matrix, note: first column is zero and corresponds to the
# intercept implicitly given in the formula
C   <- rbind(C1, C2, C3, C4, C5, C6, C7, C8, C9)   

# numerate the contrasts
colnames(C) <- NULL
rownames(C) <- c("Overall", "Older", "Younger", "Good Init", "Poor Init",
                 "Old x Good", "Old x Poor", "Young x Good", "Young x Poor") 

# remove the intercept (not needed, simtest can deal with contrast matrices
# with and without a column of zeros for the intercept
C <- C[,-1]

summary(simtest(Score ~ Treatment:AgeGroup:InitHealth,
                data=respiratory, ttype="logical",
                alternative="greater", cmatrix=C))
}
\keyword{datasets}

\eof
\name{simint}
\alias{simint}
\alias{simint.default}
\alias{simint.formula}
\alias{simint.lm}
\alias{simint.glm}
\title{ Simultaneous Confidence Intervals }
\description{Computes simultaneous intervals for several multiple procedures.}

\usage{
\method{simint}{default}(y, x=NULL, type=c("Dunnett", "Tukey",
       "Sequen", "AVE", "Changepoint", "Williams", "Marcus",
       "McDermott","Tetrade"), cmatrix=NULL, conf.level=0.95,
       alternative=c("two.sided","less", "greater"), 
       asympt=FALSE, eps=0.001, maxpts=1e+06, nlevel=NULL, 
       nzerocol=c(0,0),...)
\method{simint}{formula}(formula, data=list(), subset, na.action, whichf, ...)
\method{simint}{lm}(y, psubset=NULL, conf.level=0.95, cmatrix = NULL, 
       alternative=c("two.sided","less", "greater"), 
       asympt=FALSE, eps=0.001, maxpts=1e+06, ...)
}

\arguments{
  \item{y}{a numeric vector of responses or an object of class
           \code{\link{lm}} or \code{\link{glm}}.}
  \item{x}{a numeric matrix, the design matrix.}
  \item{type}{the type of contrast to be used.}
  \item{cmatrix}{the contrast matrix itself can be specified. If
\code{cmatrix} is defined, \code{type} is ignored.}
  \item{conf.level}{confidence level.}
  \item{alternative}{the alternative hypothesis must be
    one of \code{"two.sided"} (default), \code{"greater"} or
    \code{"less"}.  You can specify just the initial letter.}
  \item{asympt}{a logical indicating whether the (exact) t-distribution or
the normal approximation should be used.}
  \item{eps}{absolute error tolerance as double.}
  \item{maxpts}{maximum number of function values as integer.}
  \item{nlevel}{a vector containing the number of levels for each factor for
\code{type == "Tetrade"}.}
  \item{nzerocol}{ a vector of two elements defining the number of
zero-columns to add to the contrast matrix from left (the first element,
usually 1 for the intercept) and right (usually 0 if no covariables are
specified). \code{nzerocol} is automatically determined by
\code{simint.formula}.}
  \item{psubset}{a vector of integers or characters indicating for which
                 subset of coefficients of a (generalized) linear model
                 \code{y}  simultaneous confidences intervals should be
                 computed.}
  \item{formula}{a symbolic description of the model to be fit.}
  \item{data}{an optional data frame containing the variables in the model.
              By default the variables are taken from
              \code{Environment(formula)}, typically the environment from which
              \code{simint} is called.}
  \item{subset}{an optional vector specifying a subset of observations to be
          used.}
  \item{na.action}{a function which indicates what should happen when the
         data contain \code{NA}'s.  Defaults to
  \code{GetOption("na.action")}.}
  \item{whichf}{if more than one factor is given in the right hand side of
\code{formula}, \code{whichf} can be used to defined the factor to compute
contrasts of.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\details{
Computes simultaneous confidence intervals for several multiple comparisons. 
The 
implemented algorithms take the stochastical correlations between the test statistics
into account. Only single step comparisons are performed. The present function allows
for multiple comparisons of generally correlated means in general linear models under
the classical ANOVA assumptions, as well as more general approximate procedures for 
approximately normal and generally correlated parameter estimates. Either multivariate 
normal or multivariate t statistics can be used.
The interface allows the use of the multiple comparison procedures as for
example Dunnett and Tukey. 
The resulting confidence intervals are not associated with the p-values from
\code{\link{simtest}}.

See \code{\link{simtest}} for detailed information on the formula interface.

}
\value{ an object of class \code{hmtest} }
\references{ 

Frank Bretz, Alan Genz and Ludwig A. Hothorn (2001), On the numerical 
availability of multiple comparison procedures. \emph{Biometrical Journal},
\bold{43}(5), 645--656.

}
\author{ Frank Bretz <bretz@ifgb.uni-hannover.de> and  \cr 
 Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\seealso{
 \code{\link{TukeyHSD}} for the special case of Tukey contrasts.
}

\examples{
data(recovery)

# one-sided simultaneous confidence intervals for Dunnett 
# in the one-way layout
summary(simint(minutes~blanket, data=recovery, type="Dunnett", 
               conf.level=0.9, alternative="less",eps=0.0001))

# alternatively via a prespecified linear model
lmmod <- lm(minutes ~ blanket, data=recovery, contrasts=list(blanket =
            "contr.Dunnett"))
summary(simint(lmmod, psubset=2:4, conf.level=0.9,
               alternative="less",eps=0.0001))

# Tukey confidence intervals, compare with TukeyHSD

data(warpbreaks)
fm1 <- aov(breaks ~ wool + tension, data = warpbreaks)
tHSD <- TukeyHSD(fm1, "tension", ordered = FALSE)
print(tHSD)

mcHSD <- simint(breaks ~ wool + tension, data = warpbreaks, 
                whichf="tension", type="Tukey")
print(mcHSD)
plot(mcHSD)

\testonly{
  tlow <- tHSD$tension[,2]
  tupp <- tHSD$tension[,3]
  mclow <- mcHSD$conf.int[,1]
  mcupp <- mcHSD$conf.int[,2]

  a <- round(tlow, 1) 
  b <- round(mclow, 1)
  names(a) <- NULL
  names(b) <- NULL
  stopifnot(all.equal(a, b))

  a <- round(tupp, 1) 
  b <- round(mcupp, 1)
  names(a) <- NULL
  names(b) <- NULL
  stopifnot(all.equal(a, b))
}

}
\keyword{htest}

\eof
\name{simtest}
\alias{simtest.default}
\alias{simtest.formula}
\alias{simtest.lm}
\alias{simtest.glm}
\alias{simtest}
\title{ Simultaneous Comparisons }
\description{
Computes multiplicity adjusted p-value for several multiple comparisons.
}

\usage{
\method{simtest}{default}(y, x=NULL, type=c("Dunnett", "Tukey",
        "Sequen", "AVE", "Changepoint", "Williams", "Marcus",
        "McDermott","Tetrade"), cmatrix=NULL,
        alternative=c("two.sided","less", "greater"),
        asympt=FALSE, ttype=c("free","logical"), eps=0.001,
        maxpts=1e+06, nlevel=NULL, nzerocol=c(0,0),...)
\method{simtest}{formula}(formula, data=list(), subset, na.action, whichf, ...)
\method{simtest}{lm}(y, psubset=NULL, cmatrix = NULL, ttype=c("free","logical"),
         alternative=c("two.sided","less","greater"), asympt=FALSE,
         eps=0.001, maxpts=1000000, ...)
}

\arguments{
  \item{y}{a numeric vector of responses or an object of class
           \code{\link{lm}} or \code{\link{glm}}.}
  \item{x}{a numeric matrix, the design matrix.}
  \item{type}{the type of contrast to be used. If type is not specified, cmatrix has to be specified.}
  \item{cmatrix}{the contrast matrix itself can be specified. If
\code{cmatrix} is defined, \code{type} is ignored.}
  \item{alternative}{the alternative hypothesis must be
    one of \code{"two.sided"} (default), \code{"greater"} or
    \code{"less"}.  You can specify just the initial letter.}
  \item{asympt}{a logical indicating whether the (exact) t-distribution or
the normal approximation should be used.}
  \item{ttype}{Specifies whether the logical contraint method of Westfall (1997) will be used, or whether the uncontrained method will be used.}
  \item{eps}{absolute error tolerance as double.}
  \item{maxpts}{maximum number of function values as integer.}
  \item{nlevel}{a vector containing the number of levels for each factor for
    \code{type == "Tetrade"}.}
  \item{nzerocol}{ a vector of two elements defining the number of
     zero-columns to add to the contrast matrix from left (the first element,
     usually 1 for the intercept) and right (usually 0 if no covariables are
     specified). \code{nzerocol} is automatically determined by
     \code{simint.formula}.}
  \item{psubset}{a vector of integers or characters indicating for which
                 subset of coefficients of a (generalized) linear model   
                 \code{y}  simultaneous p-values should be
                 computed.}
  \item{formula}{a symbolic description of the model to be fit.}
  \item{data}{an optional data frame containing the variables in the model.
              By default the variables are taken from
              \code{Environment(formula)}, typically the environment from which
              \code{simint} is called.}
  \item{subset}{an optional vector specifying a subset of observations to be
          used.}
  \item{na.action}{a function which indicates what should happen when the
         data contain \code{NA}'s.  Defaults to
  \code{GetOption("na.action")}.}
  \item{whichf}{if more than one factor is given in the right hand side of
    \code{formula}, \code{whichf} can be used to defined the factor to compute
    contrasts of.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\details{
Computes multiplicity adjusted p-value for several multiple comparisons. The 
implemented algorithms take the logical relationships between the hypotheses 
and the stochastical correlations between the test statistics into account. 
Logical information is included via the methods described by Westfall (1997).
Stochastic information is included via the \code{\link[mvtnorm]{pmvt}} 
function. The p-values are 
generally the same as the come out in a closed test procedure using max-T-type 
statistics.  The procedure differs in a very subtle way from closed testing, 
but still controls FWE strongly under point null configurations; see Westfall
(1997).
The present function allows for multiple comparisons of generally correlated 
means in general linear models under the classical ANOVA assumptions, as well 
as more general approximate procedures for approximately normal and generally 
correlated parameter estimates.  Either multivariate normal or multivariate t 
statistics can be used. The interface allows the use of the multiple comparison 
procedures as for example Dunnett and Tukey. The resulting p-values are 
not associated  with the confidence intervals from \code{\link{simint}}.

The formula interfaces to \code{simtest} and \code{\link{simint}} are 
able to work with the following situations at the right hand side (the left
hand side is one continuous variable).

As long as the contrasts are specified for one single factor of interest,
any ANOVA or ANCOVA model can be used. If any of the covariables is again a
factor, specify the factor of interest with
the \code{whichf} option. The remaining (zero) columns are added automatically
to the contrast matrix (but you can also specify the number of zero 
columns by hand through
\code{nzerocol}). One exception of supplied contrasts which involve more
than one factor are the Tetrade contrasts for the analysis of two-fold
interactions (see \code{\link{waste}} for an example). 
In this case only the two-way layout model with interactions 
may be specified on the right hand side of `formula' (continuous covariables 
are possible). If a contrast matrix is specified (via \code{cmatrix}) and
\code{whichf} is missing, the complete design matrix is derived from the
right hand side of \code{formula} is used, whenever the their dimensions
match with those of \code{cmatrix}.
Some toy examples are given in the examples section.

In all other cases \code{\link{csimtest}} or \code{\link{csimint}} 
should be used which allow a greater flexibility and more potential
situations of use (e.g. multivariate data, contrasts involving more than 1
factor, non-linear models, ...), also the user has to compute the
estimates, df and covariance matrices on his own.
  
}
  
}
\value{ an object of class \code{hmtestp} }
\references{ 
  Peter Westfall (1997), Multiple testing of general contrasts using 
  logical constraints and  correlations. \emph{Journal of the American
  Statistical Association} \bold{92}(437), 299-36.

  Frank Bretz, Alan Genz and Ludwig A. Hothorn (2001), On the numerical 
  availability of multiple comparison procedures. \emph{Biometrical Journal},
  \bold{43}(5), 64--66.

}
\author{ Frank Bretz <bretz@ifgb.uni-hannover.de> and  \cr 
 Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\examples{
data(cholesterol)

# adjusted p-values for all-pairwise comparisons in a one-way 
# layout (tests for restricted combinations)
simtest(response ~ trt, data=cholesterol, type="Tukey", ttype="logical")

# some examples for the formula interface, statistically non-sense!

# response
y <- rnorm(21)	

# three factors
f1 <- factor(c(rep(c("A", "B", "C"), 7)))
f2 <- factor(c(rep("D", 10), rep("E", 11)))

# and one continuous covariable
x <- rnorm(21)
testdata <- cbind(as.data.frame(y), f1, f2, x)

# one factor only
summary(simtest(y ~ f1))

# one factor only, the same
summary(simtest(y ~ f1, data=testdata))

# and a continuous covariable
summary(simtest(y ~ f1 + x, data=testdata))

# without intercept
summary(simtest(y ~ f1 + x - 1, data=testdata))

# with an additional factor as covariable
# use `whichf' to specify the term in the model to 
# calculate p-values or confidence intervals for
summary(simtest(y ~ f1 + f2 + x - 1, data=testdata, whichf="f1"))

# with interaction terms
summary(simtest(y ~ f1*f2 + x - 1, data=testdata, whichf="f1"))

# inference about the interactions term
# either Tetrade contrasts 
summary(simtest(y ~ f1:f2, data=testdata, type="Tetrade"))

# or a user-defined contrast matrix
# note: this is a contrast matrix for the interactions only, 
# the column for the intercept is added automatically
simtest(y ~ f1:f2, data=testdata, cmatrix=diag(6))

# works too, if the column for the intercept is included
summary(simtest(y ~ f1:f2, data=testdata, cmatrix=cbind(0, diag(6))))

# additional covariable
summary(simtest(y ~ f1:f2 + x, data=testdata, cmatrix=diag(6)))

# again with intercept and covariables in included in cmatrix
summary(simtest(y ~ f1:f2 + x, data=testdata, 
                cmatrix=cbind(0, diag(6), 0)))

}
\keyword{htest}

\eof
\name{summary.hmtest}
\alias{summary.hmtest}
\alias{print.summary.hmtest}
\title{Summarizing Simultaneous Confidence Intervals}
\description{
  \code{summary} method for class \code{hmtest}.
}
\usage{
\method{summary}{hmtest}(object, \dots)
}
\arguments{
  \item{object}{Object of class \code{"hmtest"}.}
  \item{\dots}{further arguments to be passed to or from methods.}  
}
\details{
  Summarize all information from an \code{hmtest} object.
}
\value{
  none
}
}
\keyword{htest}

\eof
\name{summary.hmtestp}
\alias{summary.hmtestp}
\alias{print.summary.hmtestp}
\title{Summarizing Simultaneous Confidence Intervals}
\description{
  \code{summary} method for class \code{hmtestp}.
}
\usage{
\method{summary}{hmtestp}(object, \dots)
}
\arguments{
  \item{object}{Object of class \code{"hmtestp"}.}
  \item{\dots}{further arguments to be passed to or from methods.}  
}
\details{
  Summarize all information from an \code{hmtestp} object.
}
\value{
  none
}
}
\keyword{htest}

\eof
\name{tire}
\alias{tire}
\non_function{}
\title{ Tire Wear Data Set }
\usage{data(tire)}
\description{
  Operating costs per mile for two brands of tires; data set 
  taken from Westfall et al. (1999, p. 109). Confidence bands for 
  difference of regression functions.
}
\format{
  This data frame contains the following variables
  \describe{
    \item{make}{Tire brand at 2 levels: \code{A} and \code{B}.}
    \item{mph}{Miles per Hour as predictor variable.}
    \item{cost}{Response variable: operating costs per mile.}
  }
}
\details{
  See Westfall et al. (1999, p. 109)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(tire)
C <- c(0,1,-1,0,10,-10)
for ( x in seq(15,70,5) ) { C <- rbind( C,c(0,1,-1,0,x,-x) ) }
# numerate the contrasts
rownames(C) <- paste("C", 1:nrow(C), sep="")

# simultaneous confidence intervals for difference of regression functions
summary(simint(cost ~ make*mph, data=tire,
               cmatrix=C, eps=0.001))
}
\keyword{datasets}

\eof
\name{waste}
\alias{waste}
\non_function{}
\title{ Industrial Waste Data Set }
\usage{data(waste)}
\description{
  Industrial waste data set taken from Westfall et al. (1999, p. 177). 
Simultaneous confidence intervals for interaction contrasts in 
a two-way layout with interactions.
}
\format{
  This data frame contains the following variables
  \describe{
    \item{temp}{Temperature at 3 levels: \code{low}, \code{medium},
\code{high}.}
    \item{envir}{Environment at 5 levels: \code{env1} \dots \code{env5}.}
    \item{waste}{Response variable: waste output in a manufacturing plant.}
  }
}
\details{
  See Westfall et al. (1999, p. 177)
}
\source{
  P. H. Westfall, R. D. Tobias, D. Rom, R. D. Wolfinger, Y. Hochberg (1999).
  \emph{Multiple Comparisons and Multiple Tests Using the SAS System}.
  Cary, NC: SAS Institute Inc.  
}
\examples{
data(waste)
summary(aov(waste ~ envir + temp + envir*temp, data=waste))

summary(simint(waste ~ envir:temp, data=waste,
               type="Tetrade", eps=0.1))
summary(simtest(waste ~ envir:temp, data=waste,
                type="Tetrade", eps=0.1))

}

}
\keyword{datasets}

\eof
